@@ -14,6 +14,7 @@ ReTurnConfig::ReTurnConfig() :
    mTlsTurnPort(5349),
    mAltStunPort(0), // Note:  The default is to disable RFC3489 binding support
    mTurnAddress(asio::ip::address::from_string("0.0.0.0")),
+   mTurnV6Address(asio::ip::address::from_string("::0")),
    mAltStunAddress(asio::ip::address::from_string("0.0.0.0")),
    mAuthenticationMode(LongTermPassword),  // required for TURN
    mAuthenticationRealm("reTurn"),
@@ -31,7 +32,9 @@ ReTurnConfig::ReTurnConfig() :
    mLoggingFilename("reTurnServer.log"),
    mLoggingFileMaxLineCount(50000),  // 50000 about 5M size
    mDaemonize(false),
-   mPidFile("")
+   mPidFile(""),
+   mRunAsUser(""),
+   mRunAsGroup("")
 {
    mAuthenticationCredentials["test"] = "1234";
    calcUserAuthData();
@@ -45,6 +48,7 @@ void ReTurnConfig::parseConfig(int argc, char** argv, const resip::Data& default
    mTlsTurnPort = getConfigUnsignedShort("TlsTurnPort", 5349);
    mAltStunPort = getConfigUnsignedShort("AltStunPort", 0);
    mTurnAddress = asio::ip::address::from_string(getConfigData("TurnAddress", "0.0.0.0").c_str());
+   mTurnV6Address = asio::ip::address::from_string(getConfigData("TurnV6Address", "::0").c_str());
    mAltStunAddress = asio::ip::address::from_string(getConfigData("AltStunAddress", "0.0.0.0").c_str());
    int authMode = getConfigUnsignedShort("AuthenticationMode", 2);
    switch(authMode)
@@ -71,6 +75,8 @@ void ReTurnConfig::parseConfig(int argc, char** argv, const resip::Data& default
    mLoggingFileMaxLineCount = getConfigUnsignedLong("LogFileMaxLines", 50000);
    mDaemonize = getConfigBool("Daemonize", false);
    mPidFile = getConfigData("PidFile", "");
+   mRunAsUser = getConfigData("RunAsUser", "");
+   mRunAsGroup = getConfigData("RunAsGroup", "");
 
    // fork is not possible on Windows
 #ifdef WIN32
