@@ -1,4 +1,5 @@
 #include <iostream>
+#include <csignal>
 #include <string>
 #include <asio.hpp>
 #include <boost/bind.hpp>
@@ -96,6 +97,12 @@ reTurn::ReTurnServerProcess::main(int argc, char* argv[])
       boost::shared_ptr<reTurn::UdpServer> a2p1StunUdpServer;
       boost::shared_ptr<reTurn::UdpServer> a2p2StunUdpServer;
 
+#ifdef USE_IPV6
+      boost::shared_ptr<reTurn::UdpServer> udpV6TurnServer;
+      boost::shared_ptr<reTurn::TcpServer> tcpV6TurnServer;
+      boost::shared_ptr<reTurn::TlsServer> tlsV6TurnServer;
+#endif
+
       // The one and only RequestHandler - if altStunPort is non-zero, then assume RFC3489 support is enabled and pass settings to request handler
       reTurn::RequestHandler requestHandler(turnManager, 
          reTurnConfig.mAltStunPort != 0 ? &reTurnConfig.mTurnAddress : 0, 
@@ -107,6 +114,12 @@ reTurn::ReTurnServerProcess::main(int argc, char* argv[])
       tcpTurnServer.reset(new reTurn::TcpServer(ioService, requestHandler, reTurnConfig.mTurnAddress, reTurnConfig.mTurnPort));
       tlsTurnServer.reset(new reTurn::TlsServer(ioService, requestHandler, reTurnConfig.mTurnAddress, reTurnConfig.mTlsTurnPort));
 
+#ifdef USE_IPV6
+      udpV6TurnServer.reset(new reTurn::UdpServer(ioService, requestHandler, reTurnConfig.mTurnV6Address, reTurnConfig.mTurnPort));
+      tcpV6TurnServer.reset(new reTurn::TcpServer(ioService, requestHandler, reTurnConfig.mTurnV6Address, reTurnConfig.mTurnPort));
+      tlsV6TurnServer.reset(new reTurn::TlsServer(ioService, requestHandler, reTurnConfig.mTurnV6Address, reTurnConfig.mTlsTurnPort));
+#endif
+
       if(reTurnConfig.mAltStunPort != 0) // if alt stun port is non-zero, then RFC3489 support is enabled
       {
          a1p2StunUdpServer.reset(new reTurn::UdpServer(ioService, requestHandler, reTurnConfig.mTurnAddress, reTurnConfig.mAltStunPort));
@@ -125,6 +138,19 @@ reTurn::ReTurnServerProcess::main(int argc, char* argv[])
       tcpTurnServer->start();
       tlsTurnServer->start();
 
+#ifdef USE_IPV6
+      udpV6TurnServer->start();
+      tcpV6TurnServer->start();
+      tlsV6TurnServer->start();
+#endif
+
+      // Drop privileges (can do this now that sockets are bound)
+      if(!reTurnConfig.mRunAsUser.empty())
+      {
+         InfoLog( << "Trying to drop privileges, configured uid = " << reTurnConfig.mRunAsUser << " gid = " << reTurnConfig.mRunAsGroup);
+         dropPrivileges(reTurnConfig.mRunAsUser, reTurnConfig.mRunAsGroup);
+      }
+
 #ifdef _WIN32
       // Set console control handler to allow server to be stopped.
       console_ctrl_function = boost::bind(&asio::io_service::stop, &ioService);
