@@ -120,7 +120,7 @@ ReproRunner::ReproRunner()
    , mLemurs(0)
    , mBaboons(0)
    , mProxy(0)
-   , mWebAdmin(0)
+   , mWebAdminList(0)
    , mWebAdminThread(0)
    , mRegistrar(0)
    , mDum(0)
@@ -130,8 +130,7 @@ ReproRunner::ReproRunner()
    , mRegSyncServerV4(0)
    , mRegSyncServerV6(0)
    , mRegSyncServerThread(0)
-   , mCommandServerV4(0)
-   , mCommandServerV6(0)
+   , mCommandServerList(0)
    , mCommandServerThread(0)
    , mCongestionManager(0)
 {
@@ -181,9 +180,10 @@ ReproRunner::run(int argc, char** argv)
    // Initialize resip logger
    GenericLogImpl::MaxByteCount = mProxyConfig->getConfigUnsignedLong("LogFileMaxBytes", 5242880 /*5 Mb */);
    Data loggingType = mProxyConfig->getConfigData("LoggingType", "cout", true);
+   Data mAppName = mProxyConfig->getConfigData("LoggingInstanceName", mArgv[0], true);
    Log::initialize(loggingType, 
                    mProxyConfig->getConfigData("LogLevel", "INFO", true), 
-                   mArgv[0], 
+                   mAppName, 
                    mProxyConfig->getConfigData("LogFilename", "repro.log", true).c_str(),
                    isEqualNoCase(loggingType, "file") ? &g_ReproLogger : 0); // if logging to file then write WARNINGS, and Errors to console still
 
@@ -195,6 +195,15 @@ ReproRunner::run(int argc, char** argv)
       return false;
    }
 
+   // Drop privileges (can do this now that sockets are bound)
+   Data runAsUser = mProxyConfig->getConfigData("RunAsUser", "", true);
+   Data runAsGroup = mProxyConfig->getConfigData("RunAsGroup", "", true); 
+   if(!runAsUser.empty())
+   {
+      InfoLog( << "Trying to drop privileges, configured uid = " << runAsUser << " gid = " << runAsGroup);
+      dropPrivileges(runAsUser, runAsGroup);
+   }
+
    // Create datastore
    if(!createDatastore())
    {
@@ -356,8 +365,11 @@ ReproRunner::cleanupObjects()
    {
       // We leave command server running during restart
       delete mCommandServerThread; mCommandServerThread = 0;
-      delete mCommandServerV6; mCommandServerV6 = 0;
-      delete mCommandServerV4; mCommandServerV4 = 0;
+      for(std::list<CommandServer*>::iterator it = mCommandServerList->begin(); it != mCommandServerList->end(); it++)
+      {
+         delete (*it);
+      }
+      delete mCommandServerList; mCommandServerList = 0;
    }
    delete mRegSyncServerThread; mRegSyncServerThread = 0;
    delete mRegSyncServerV6; mRegSyncServerV6 = 0;
@@ -370,7 +382,11 @@ ReproRunner::cleanupObjects()
    delete mDum; mDum = 0;
    delete mRegistrar; mRegistrar = 0;
    delete mWebAdminThread; mWebAdminThread = 0;
-   delete mWebAdmin; mWebAdmin = 0;
+   for(std::list<WebAdmin*>::iterator it = mWebAdminList->begin(); it != mWebAdminList->end(); it++)
+   {
+      delete (*it);
+   }
+   delete mWebAdminList; mWebAdminList = 0;
    delete mProxy; mProxy = 0;
    delete mBaboons; mBaboons = 0;
    delete mLemurs; mLemurs = 0;
@@ -408,14 +424,15 @@ ReproRunner::createSipStack()
    Security* security = 0;
    Compression* compression = 0;
 #ifdef USE_SSL
-#ifdef WIN32
-   Data certPath("C:\\sipCerts");
-#else 
-   Data certPath(getenv("HOME"));
-   certPath += "/.sipCerts";
-#endif
-   mProxyConfig->getConfigValue("CertificatePath", certPath);
-   security = new Security(certPath);
+   Data certPath = mProxyConfig->getConfigData("CertificatePath", "");
+   if(certPath.empty())
+   {
+      security = new Security();
+   }
+   else
+   {
+      security = new Security(certPath);
+   }
    Data caDir;
    mProxyConfig->getConfigValue("CADirectory", caDir);
    if(!caDir.empty())
@@ -735,6 +752,8 @@ ReproRunner::createDialogUsageManager()
 #endif
    }
 
+   mSipAuthDisabled = mProxyConfig->getConfigBool("DisableAuth", false);
+
    if (mDum)
    {
       bool enableCertAuth = mProxyConfig->getConfigBool("EnableCertificateAuthenticator", false);
@@ -752,8 +771,6 @@ ReproRunner::createDialogUsageManager()
          mDum->addIncomingFeature(certAuth);
       }
 
-      mSipAuthDisabled = mProxyConfig->getConfigBool("DisableAuth", false);
-
       // If Authentication is enabled, then configure DUM to authenticate requests
       if (!mSipAuthDisabled)
       {
@@ -869,24 +886,80 @@ ReproRunner::populateRegistrations()
 bool
 ReproRunner::createWebAdmin()
 {
-   assert(!mWebAdmin);
+   assert(!mWebAdminList);
    assert(!mWebAdminThread);
+
+   std::vector<resip::Data> httpServerBindAddresses;
+   mProxyConfig->getConfigValue("HttpBindAddress", httpServerBindAddresses);
    int httpPort = mProxyConfig->getConfigInt("HttpPort", 5080);
-   if (httpPort) 
+
+   mWebAdminList = new std::list<WebAdmin*>;
+   if(httpPort)
    {
-      mWebAdmin = new WebAdmin(*mProxy,
-                               *mRegistrationPersistenceManager, 
-                               mHttpRealm, 
-                               httpPort);
-      if (!mWebAdmin->isSane())
+      if(httpServerBindAddresses.empty())
       {
-         CritLog(<<"Failed to start the WebAdmin");
-         cleanupObjects();
-         return false;
+          if(mUseV4)
+          {
+             httpServerBindAddresses.push_back("0.0.0.0");
+          }
+           if(mUseV6)
+          {
+             httpServerBindAddresses.push_back("::");
+          }
+      }
+
+      for(std::vector<resip::Data>::iterator it = httpServerBindAddresses.begin(); it != httpServerBindAddresses.end(); it++)
+      {
+         if(mUseV4 && DnsUtil::isIpV4Address(*it)) 
+         {
+            WebAdmin* WebAdminV4 = new WebAdmin(*mProxy,
+                                                *mRegistrationPersistenceManager, 
+                                                mHttpRealm, 
+                                                httpPort,
+                                                V4,
+                                                *it);
+
+            if (!WebAdminV4->isSane())
+            {
+               CritLog(<<"Failed to start WebAdminV4");
+               cleanupObjects();
+               return false;
+            }
+
+            mWebAdminList->push_back(WebAdminV4);
+         }
+
+         if(mUseV6 && DnsUtil::isIpV6Address(*it)) 
+         {
+            WebAdmin* WebAdminV6 = new WebAdmin(*mProxy,
+                                                *mRegistrationPersistenceManager, 
+                                                mHttpRealm, 
+                                                httpPort,
+                                                V6,
+                                                *it);
+
+            if (!WebAdminV6->isSane())
+            {
+               CritLog(<<"Failed to start WebAdminV6");
+               cleanupObjects();
+               return false;
+            }
+
+            mWebAdminList->push_back(WebAdminV6);
+         }
+      }
+
+      // This shouldn't happen because it would return false before
+      // it reached this point
+      if(!mWebAdminList->empty())
+      {
+         mWebAdminThread = new WebAdminThread(*mWebAdminList);
+         return true;
       }
-      mWebAdminThread = new WebAdminThread(*mWebAdmin);
    }
-   return true;
+
+   CritLog(<<"Failed to start any WebAdmin");
+   return false;
 }
 
 void
@@ -924,26 +997,62 @@ ReproRunner::createRegSync()
 void
 ReproRunner::createCommandServer()
 {
-   assert(!mCommandServerV4);
-   assert(!mCommandServerV6);
+   assert(!mCommandServerList);
    assert(!mCommandServerThread);
+
+   std::vector<resip::Data> commandServerBindAddresses;
+   mProxyConfig->getConfigValue("CommandBindAddress", commandServerBindAddresses);
    int commandPort = mProxyConfig->getConfigInt("CommandPort", 5081);
+
+   mCommandServerList = new std::list<CommandServer*>;
    if(commandPort != 0)
    {
-      std::list<CommandServer*> commandServerList;
-      if(mUseV4) 
+      if(commandServerBindAddresses.empty())
       {
-         mCommandServerV4 = new CommandServer(*this, commandPort, V4);
-         commandServerList.push_back(mCommandServerV4);
+          if(mUseV4)
+          {
+             commandServerBindAddresses.push_back("0.0.0.0");
+          }
+           if(mUseV6)
+          {
+             commandServerBindAddresses.push_back("::");
+          }
       }
-      if(mUseV6) 
+
+      for(std::vector<resip::Data>::iterator it = commandServerBindAddresses.begin(); it != commandServerBindAddresses.end(); it++)
       {
-         mCommandServerV6 = new CommandServer(*this, commandPort, V6);
-         commandServerList.push_back(mCommandServerV6);
+         if(mUseV4 && DnsUtil::isIpV4Address(*it))
+         {
+            CommandServer* CommandServerV4 = new CommandServer(*this, *it, commandPort, V4);
+
+            if(CommandServerV4->isSane())
+            {
+               mCommandServerList->push_back(CommandServerV4);
+            }
+            else
+            {
+               CritLog(<<"Failed to start CommandServerV4");
+            }
+         }
+
+         if(mUseV6 && DnsUtil::isIpV6Address(*it))
+         {
+            CommandServer* CommandServerV6 = new CommandServer(*this, *it, commandPort, V6);
+
+            if(CommandServerV6->isSane())
+            {
+               mCommandServerList->push_back(CommandServerV6);
+            }
+            else
+            {
+               CritLog(<<"Failed to start CommandServerV6");
+            }
+         }
       }
-      if(!commandServerList.empty())
+
+      if(!mCommandServerList->empty())
       {
-         mCommandServerThread = new CommandServerThread(commandServerList);
+         mCommandServerThread = new CommandServerThread(*mCommandServerList);
       }
    }
 }
@@ -1035,6 +1144,8 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
          // Transport1Interface = 192.168.1.106:5061
          // Transport1Type = TLS
          // Transport1TlsDomain = sipdomain.com
+         // Transport1TlsCertificate = /etc/ssl/crt/sipdomain.com.pem
+         // Transport1TlsPrivateKey = /etc/ssl/private/sipdomain.com.pem
          // Transport1TlsClientVerification = None
          // Transport1RecordRouteUri = sip:sipdomain.com;transport=TLS
          // Transport1RcvBufLen = 2000
@@ -1046,6 +1157,8 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
          {
             Data typeSettingKey(settingKeyBase + "Type");
             Data tlsDomainSettingKey(settingKeyBase + "TlsDomain");
+            Data tlsCertificateSettingKey(settingKeyBase + "TlsCertificate");
+            Data tlsPrivateKeySettingKey(settingKeyBase + "TlsPrivateKey");
             Data tlsCVMSettingKey(settingKeyBase + "TlsClientVerification");
             Data recordRouteUriSettingKey(settingKeyBase + "RecordRouteUri");
             Data rcvBufSettingKey(settingKeyBase + "RcvBufLen");
@@ -1053,7 +1166,9 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
             // Parse out interface settings
             ParseBuffer pb(interfaceSettings);
             anchor = pb.position();
-            pb.skipToChar(':');
+            pb.skipToEnd();
+            pb.skipBackToChar(':');  // For IPv6 the last : should be the port
+            pb.skipBackChar();
             if(!pb.eof())
             {
                Data ipAddr;
@@ -1078,6 +1193,8 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
                   CritLog(<< "Unknown transport type found in " << typeSettingKey << " setting: " << mProxyConfig->getConfigData(typeSettingKey, "UDP"));
                }
                Data tlsDomain = mProxyConfig->getConfigData(tlsDomainSettingKey, "");
+               Data tlsCertificate = mProxyConfig->getConfigData(tlsCertificateSettingKey, "");
+               Data tlsPrivateKey = mProxyConfig->getConfigData(tlsPrivateKeySettingKey, "");
                Data tlsCVMValue = mProxyConfig->getConfigData(tlsCVMSettingKey, "NONE");
                SecurityTypes::TlsClientVerificationMode cvm = SecurityTypes::None;
                if(isEqualNoCase(tlsCVMValue, "Optional"))
@@ -1092,6 +1209,25 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
                {
                   CritLog(<< "Unknown TLS client verification mode found in " << tlsCVMSettingKey << " setting: " << tlsCVMValue);
                }
+
+#if defined(USE_SSL)
+               // Make sure certificate material available before trying to instantiate Transport
+               if(isSecure(tt))
+               {
+                  Security* security = mSipStack->getSecurity();
+                  assert(security != 0);
+                  // FIXME: see comments about CertificatePath
+                  if(!tlsCertificate.empty())
+                  {
+                     security->addDomainCertPEM(tlsDomain, Data::fromFile(tlsCertificate));
+                  }
+                  if(!tlsPrivateKey.empty())
+                  {
+                     security->addDomainPrivateKeyPEM(tlsDomain, Data::fromFile(tlsPrivateKey));
+                  }
+               }
+#endif
+
                int rcvBufLen = mProxyConfig->getConfigInt(rcvBufSettingKey, 0);
                Transport *t = mSipStack->addTransport(tt,
                                  port,
@@ -1180,6 +1316,8 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
          int tlsPort = mProxyConfig->getConfigInt("TLSPort", 5061);
          int dtlsPort = mProxyConfig->getConfigInt("DTLSPort", 0);
          Data tlsDomain = mProxyConfig->getConfigData("TLSDomainName", "");
+         Data tlsCertificate = mProxyConfig->getConfigData("TLSCertificate", "");
+         Data tlsPrivateKey = mProxyConfig->getConfigData("TLSPrivateKey", "");
          Data tlsCVMValue = mProxyConfig->getConfigData("TLSClientVerification", "NONE");
          SecurityTypes::TlsClientVerificationMode cvm = SecurityTypes::None;
          if(isEqualNoCase(tlsCVMValue, "Optional"))
@@ -1195,6 +1333,27 @@ ReproRunner::addTransports(bool& allTransportsSpecifyRecordRoute)
             CritLog(<< "Unknown TLS client verification mode found in TLSClientVerification setting: " << tlsCVMValue);
          }
 
+#if defined(USE_SSL)
+         // Make sure certificate material available before trying to instantiate Transport
+         if (tlsPort || dtlsPort)
+         {
+            Security* security = mSipStack->getSecurity();
+            assert(security != 0);
+            // FIXME: should check that EITHER CertificatePath was set or both of these
+            // are supplied
+            // In any case, it will still give a helpful error when it fails to
+            // create the transport
+            if(!tlsCertificate.empty())
+            {
+               security->addDomainCertPEM(tlsDomain, Data::fromFile(tlsCertificate));
+            }
+            if(!tlsPrivateKey.empty())
+            {
+               security->addDomainPrivateKeyPEM(tlsDomain, Data::fromFile(tlsPrivateKey));
+            }
+         }
+#endif
+
          if (udpPort)
          {
             if (mUseV4) mSipStack->addTransport(UDP, udpPort, V4, StunEnabled);
@@ -1248,6 +1407,7 @@ ReproRunner::loadCommonNameMappings()
    ifstream mappingsFile(mappingsFileName.c_str());
    if(!mappingsFile)
    {
+      ErrLog(<< "failed to open mappings file: " << mappingsFileName << ", aborting");
       throw std::runtime_error("Error opening/reading mappings file");
    }
 
