@@ -20,6 +20,8 @@
 
 using namespace resip;
 
+static const int UnreasonablyLowExpirationThreshold = 7;  // The threshold before which we consider a contacts expiry to be unreasonably low
+
 ClientRegistrationHandle
 ClientRegistration::getHandle()
 {
@@ -224,15 +226,18 @@ ClientRegistration::removeMyBindings(bool stopRegisteringWhenDone)
 class ClientRegistrationRemoveMyBindings : public DumCommandAdapter
 {
 public:
-   ClientRegistrationRemoveMyBindings(ClientRegistration& clientRegistration, bool stopRegisteringWhenDone)
-      : mClientRegistration(clientRegistration),
+   ClientRegistrationRemoveMyBindings(const ClientRegistrationHandle& clientRegistrationHandle, bool stopRegisteringWhenDone)
+      : mClientRegistrationHandle(clientRegistrationHandle),
         mStopRegisteringWhenDone(stopRegisteringWhenDone)
    {
    }
 
    virtual void executeCommand()
    {
-      mClientRegistration.removeMyBindings(mStopRegisteringWhenDone);
+      if(mClientRegistrationHandle.isValid())
+      {
+         mClientRegistrationHandle->removeMyBindings(mStopRegisteringWhenDone);
+      }
    }
 
    virtual EncodeStream& encodeBrief(EncodeStream& strm) const
@@ -240,14 +245,14 @@ public:
       return strm << "ClientRegistrationRemoveMyBindings";
    }
 private:
-   ClientRegistration& mClientRegistration;
+   ClientRegistrationHandle mClientRegistrationHandle;
    bool mStopRegisteringWhenDone;
 };
 
 void
 ClientRegistration::removeMyBindingsCommand(bool stopRegisteringWhenDone)
 {
-   mDum.post(new ClientRegistrationRemoveMyBindings(*this, stopRegisteringWhenDone));
+   mDum.post(new ClientRegistrationRemoveMyBindings(getHandle(), stopRegisteringWhenDone));
 }
 
 void 
@@ -323,15 +328,18 @@ ClientRegistration::end()
 class ClientRegistrationEndCommand : public DumCommandAdapter
 {
 public:
-   ClientRegistrationEndCommand(ClientRegistration& clientRegistration)
-      : mClientRegistration(clientRegistration)
+   ClientRegistrationEndCommand(const ClientRegistrationHandle& clientRegistrationHandle)
+      : mClientRegistrationHandle(clientRegistrationHandle)
    {
 
    }
 
    virtual void executeCommand()
    {
-      mClientRegistration.end();
+      if(mClientRegistrationHandle.isValid())
+      {
+         mClientRegistrationHandle->end();
+      }
    }
 
    virtual EncodeStream& encodeBrief(EncodeStream& strm) const
@@ -339,13 +347,13 @@ public:
       return strm << "ClientRegistrationEndCommand";
    }
 private:
-   ClientRegistration& mClientRegistration;
+   ClientRegistrationHandle mClientRegistrationHandle;
 };
 
 void
 ClientRegistration::endCommand()
 {
-   mDum.post(new ClientRegistrationEndCommand(*this));
+   mDum.post(new ClientRegistrationEndCommand(getHandle()));
 }
 
 EncodeStream& 
@@ -485,7 +493,7 @@ ClientRegistration::dispatch(const SipMessage& msg)
 
          if (expiry != 0 && expiry != UINT_MAX)
          {
-            if(expiry>=7)
+            if(expiry >= UnreasonablyLowExpirationThreshold)
             {
                int exp = Helper::aBitSmallerThan(expiry);
                mExpires = exp + Timer::getTimeSecs();
@@ -765,20 +773,55 @@ ClientRegistration::calculateExpiry(const SipMessage& reg200) const
 
    const NameAddrs& contacts(reg200.header(h_Contacts));
 
+   // We are going to track two things here:
+   // 1. expiry - the lowest expiration value of all of our contacts
+   // 2. reasonableExpiry - the lowest expiration value of all of our contacts
+   //                       that is above the UnreasonablyLowExpirationThreshold (7 seconds)
+   // Before we return, if expiry is less than UnreasonablyLowExpirationThreshold
+   // but we had another contact that had a reasonable expiry value, then return
+   // that value instead.  This logic covers a very interesting scenario:
+   //
+   // Consider the case where we are registered over TCP due to DNS SRV record
+   // configuration.  Let's say an administrator reconfigures the DNS records to
+   // now make UDP the preferred transport.  When we re-register we will now
+   // send the re-registration message over UDP.  This will cause our contact
+   // address to be changed (ie: ;tranport=tcp will no longer exist).  So for a
+   // short period of time the registrar will return two contacts to us, both 
+   // belonging to us, one for TCP and one for UDP.  The TCP one will expire in
+   // a short amount of time, and if we return this expiry to the dispatch() 
+   // method then it will cause the ClientRegistration to end (see logic in 
+   // dispatch() that prints out the error "Server is using an unreasonably low 
+   // expiry: "...
+   unsigned long reasonableExpiry = 0xFFFFFFFF;
+
    for(NameAddrs::const_iterator c=contacts.begin();c!=contacts.end();++c)
    {
       // Our expiry is never going to increase if we find one of our contacts, 
       // so if the expiry is not lower, we just ignore it. For registrars that
       // leave our requested expiry alone, this code ends up being pretty quick,
-      // especially if there aren't contacts from other endpoints laying around.
-      if(c->isWellFormed() &&
-         c->exists(p_expires) && 
-         c->param(p_expires) < expiry &&
-         contactIsMine(*c))
+      // especially if there aren't contacts from other endpoints laying around.     
+      if(c->isWellFormed() && c->exists(p_expires))
       {
-         expiry=c->param(p_expires);
+         unsigned long contactExpires = c->param(p_expires);
+         if((contactExpires < expiry ||
+             contactExpires < reasonableExpiry) &&
+            contactIsMine(*c))
+         {
+            expiry = contactExpires;
+            if(contactExpires >= UnreasonablyLowExpirationThreshold)
+            {
+                reasonableExpiry = contactExpires;
+            }
+         }
       }
    }
+   // If expiry is less than UnreasonablyLowExpirationThreshold and we have another
+   // contact that has a reasonable expiry value, then return that value instead.
+   // See large comment above for more details.
+   if(expiry < UnreasonablyLowExpirationThreshold && reasonableExpiry != 0xFFFFFFFF)
+   {
+       expiry = reasonableExpiry;
+   }
    return expiry;
 }
 
