@@ -22,7 +22,7 @@ ServerInviteSession::ServerInviteSession(DialogUsageManager& dum, Dialog& dialog
    : InviteSession(dum, dialog),
      mFirstRequest(request),
      m1xx(new SipMessage),
-     mCurrentRetransmit1xx(0)
+     mCurrentRetransmit1xxSeq(0)
 {
    assert(request.isRequest());
    mState = UAS_Start;
@@ -96,8 +96,8 @@ ServerInviteSession::redirect(const NameAddrs& contacts, int code)
 class ServerInviteSessionRedirectCommand : public DumCommandAdapter
 {
 public:
-   ServerInviteSessionRedirectCommand(ServerInviteSession& serverInviteSession, const NameAddrs& contacts, int code)
-      : mServerInviteSession(serverInviteSession),
+   ServerInviteSessionRedirectCommand(const ServerInviteSessionHandle& serverInviteSessionHandle, const NameAddrs& contacts, int code)
+      : mServerInviteSessionHandle(serverInviteSessionHandle),
       mContacts(contacts),
       mCode(code)
    {
@@ -106,7 +106,10 @@ public:
 
    virtual void executeCommand()
    {
-      mServerInviteSession.redirect(mContacts, mCode);
+      if(mServerInviteSessionHandle.isValid())
+      {
+         mServerInviteSessionHandle->redirect(mContacts, mCode);
+      }
    }
 
    virtual EncodeStream& encodeBrief(EncodeStream& strm) const
@@ -114,7 +117,7 @@ public:
       return strm << "ServerInviteSessionRedirectCommand";
    }
 private:
-   ServerInviteSession& mServerInviteSession;
+   ServerInviteSessionHandle mServerInviteSessionHandle;
    NameAddrs mContacts;
    int mCode;
 };
@@ -122,7 +125,7 @@ private:
 void 
 ServerInviteSession::redirectCommand(const NameAddrs& contacts, int code)
 {
-   mDum.post(new ServerInviteSessionRedirectCommand(*this, contacts, code));
+   mDum.post(new ServerInviteSessionRedirectCommand(getHandle(), contacts, code));
 }
 
 void 
@@ -189,15 +192,18 @@ ServerInviteSession::provisional(int code, bool earlyFlag)
 class ServerInviteSessionProvisionalCommand : public DumCommandAdapter
 {
 public:
-   ServerInviteSessionProvisionalCommand(ServerInviteSession& serverInviteSession, int statusCode)
-      : mServerInviteSession(serverInviteSession),
+   ServerInviteSessionProvisionalCommand(const ServerInviteSessionHandle& serverInviteSessionHandle, int statusCode)
+      : mServerInviteSessionHandle(serverInviteSessionHandle),
         mStatusCode(statusCode)
    {
    }
 
    virtual void executeCommand()
    {
-      mServerInviteSession.provisional(mStatusCode);
+      if(mServerInviteSessionHandle.isValid())
+      {
+         mServerInviteSessionHandle->provisional(mStatusCode);
+      }
    }
 
    virtual EncodeStream& encodeBrief(EncodeStream& strm) const
@@ -205,14 +211,14 @@ public:
       return strm << "ServerInviteSessionProvisionalCommand";
    }
 private:
-   ServerInviteSession& mServerInviteSession;
+   ServerInviteSessionHandle mServerInviteSessionHandle;
    int mStatusCode;
 };
 
 void 
 ServerInviteSession::provisionalCommand(int statusCode)
 {
-   mDum.post(new ServerInviteSessionProvisionalCommand(*this, statusCode));
+   mDum.post(new ServerInviteSessionProvisionalCommand(getHandle(), statusCode));
 }
 
 void
@@ -592,15 +598,18 @@ ServerInviteSession::accept(int code)
 class ServerInviteSessionAcceptCommand : public DumCommandAdapter
 {
 public:
-   ServerInviteSessionAcceptCommand(ServerInviteSession& serverInviteSession, int statusCode)
-      : mServerInviteSession(serverInviteSession),
+   ServerInviteSessionAcceptCommand(const ServerInviteSessionHandle& serverInviteSessionHandle, int statusCode)
+      : mServerInviteSessionHandle(serverInviteSessionHandle),
         mStatusCode(statusCode)
    {
    }
 
    virtual void executeCommand()
    {
-      mServerInviteSession.accept(mStatusCode);
+      if(mServerInviteSessionHandle.isValid())
+      {
+         mServerInviteSessionHandle->accept(mStatusCode);
+      }
    }
 
    virtual EncodeStream& encodeBrief(EncodeStream& strm) const
@@ -608,14 +617,14 @@ public:
       return strm << "ServerInviteSessionAcceptCommand";
    }
 private:
-   ServerInviteSession& mServerInviteSession;
+   ServerInviteSessionHandle mServerInviteSessionHandle;
    int mStatusCode;
 };
 
 void 
 ServerInviteSession::acceptCommand(int statusCode)
 {
-   mDum.post(new ServerInviteSessionAcceptCommand(*this, statusCode));
+   mDum.post(new ServerInviteSessionAcceptCommand(getHandle(), statusCode));
 }
 
 void 
@@ -707,7 +716,7 @@ ServerInviteSession::dispatch(const DumTimeout& timeout)
 {
    if (timeout.type() == DumTimeout::Retransmit1xx)
    {
-      if (mCurrentRetransmit1xx && m1xx->header(h_CSeq).sequence() == timeout.seq())  // If timer isn't stopped and this timer is for last 1xx sent, then resend
+      if (timeout.seq() == mCurrentRetransmit1xxSeq)  // If timer isn't stopped and this timer is for last 1xx sent, then resend
       {
          send(m1xx);
          startRetransmit1xxTimer();
@@ -1211,11 +1220,10 @@ void
 ServerInviteSession::startRetransmit1xxTimer()
 {
    // RFC3261 13.3.1 says the UAS must send a non-100 provisional response every minute, to handle the possiblity of lost provisional responses
-   mCurrentRetransmit1xx = mDialog.mDialogSet.getUserProfile()->get1xxRetransmissionTime();  
-   if(mCurrentRetransmit1xx > 0)
-   {	
-      unsigned int seq = m1xx->header(h_CSeq).sequence();
-      mDum.addTimer(DumTimeout::Retransmit1xx, mCurrentRetransmit1xx, getBaseHandle(), seq);
+   int retransmissionTime = mDialog.mDialogSet.getUserProfile()->get1xxRetransmissionTime();
+   if(retransmissionTime > 0 && m1xx->header(resip::h_StatusLine).statusCode() > 100)
+   {
+      mDum.addTimer(DumTimeout::Retransmit1xx, retransmissionTime, getBaseHandle(), ++mCurrentRetransmit1xxSeq);
    }
 }
 
@@ -1225,7 +1233,7 @@ ServerInviteSession::sendProvisional(int code, bool earlyFlag)
    mDialog.makeResponse(*m1xx, mFirstRequest, code);
    if(!earlyFlag)
    {
-	   m1xx->setContents(0);  // clear contents if present
+      m1xx->setContents(0);  // clear contents if present
    }
    else
    {
@@ -1270,8 +1278,8 @@ ServerInviteSession::sendAccept(int code, Contents* offerAnswer)
    {
       setOfferAnswer(*mInvite200, offerAnswer);
    }
-   mCurrentRetransmit1xx = 0; // Stop the 1xx timer
-   startRetransmit200Timer(); // 2xx timer
+   mCurrentRetransmit1xxSeq++; // Stop the 1xx timer - causes timer to be ignored on expirey
+   startRetransmit200Timer();  // 2xx timer
    DumHelper::setOutgoingEncryptionLevel(*mInvite200, mCurrentEncryptionLevel);
 
    if (mDum.mDialogEventStateManager)
