@@ -1,4 +1,8 @@
 // sipX includes
+#ifdef WIN32
+#include <stdint.h>       // Use Visual Studio's stdint.h
+#define _MSC_STDINT_H_    // This define will ensure that stdint.h in sipXport tree is not used
+#endif
 #include <sdp/SdpCodec.h>
 #include <os/OsConfigDb.h>
 #include <mp/MpCodecFactory.h>
@@ -70,14 +74,24 @@ ConversationManager::ConversationManager(bool localAudioEnabled, MediaInterfaceM
 
    // Create MediaInterface
    MpCodecFactory *pCodecFactory = MpCodecFactory::getMpCodecFactory();
+   // For dynamic loading, we need to force the codecs to be loaded
+   // somehow, this should be exposed through the API
+   //pCodecFactory->loadAllDynCodecs("/tmp/codecs", "");
    unsigned int count = 0;
    const MppCodecInfoV1_1 **codecInfoArray;
    pCodecFactory->getCodecInfoArray(count, codecInfoArray);
 
    if(count == 0)
    {
-      ErrLog( << "No codec plugins found.  Cannot start.");
-      exit(-1);
+      // Try to load plugin modules, if possible...
+      InfoLog(<<"No statically linked codecs, trying to load codec plugin modules with dlopen()");
+      pCodecFactory->loadAllDynCodecs(NULL, "");
+      pCodecFactory->getCodecInfoArray(count, codecInfoArray);
+      if(count == 0)
+      {
+         ErrLog( << "No codec plugins found.  Cannot start.");
+         exit(-1);
+      }
    }
 
    InfoLog( << "Loaded codecs are:");
