@@ -644,12 +644,10 @@ Helper::computeUniqueBranch()
    return result;
 }
 
-
-static Data localhostname = DnsUtil::getLocalHostName();
 Data
 Helper::computeCallId()
 {
-   Data hostAndSalt(localhostname + Random::getRandomHex(16));
+   Data hostAndSalt(DnsUtil::getLocalHostName() + Random::getRandomHex(16));
 #ifndef USE_SSL // .bwc. None of this is neccessary if we're using openssl
 #if defined(__linux__) || defined(__APPLE__)
    pid_t pid = getpid();
@@ -2190,14 +2188,28 @@ Helper::isClientBehindNAT(const SipMessage& request, bool privateToPublicOnly)
    {
       if(privateToPublicOnly)
       {
-         if(Tuple(request.header(h_Vias).front().sentHost(), 0, UNKNOWN_TRANSPORT).isPrivateAddress() &&
-            !Tuple(request.header(h_Vias).front().param(p_received), 0, UNKNOWN_TRANSPORT).isPrivateAddress())
+         // Ensure the via host is an IP address (note: web-rtc uses hostnames here instead)
+         if(DnsUtil::isIpV4Address(request.header(h_Vias).front().sentHost()) 
+#ifdef USE_IPv6
+             || DnsUtil::isIpV6Address(request.header(h_Vias).front().sentHost())
+#endif
+             )
          {
-            return true;
+            if(Tuple(request.header(h_Vias).front().sentHost(), 0, UNKNOWN_TRANSPORT).isPrivateAddress() &&
+                !Tuple(request.header(h_Vias).front().param(p_received), 0, UNKNOWN_TRANSPORT).isPrivateAddress())
+            {
+                return true;
+            }
+            else
+            {
+                return false;
+            }
          }
          else
          {
-            return false;
+             // In this case the via host is likely a hostname (possible with web-rtc) and we will assume the
+             // client is behind a NAT, even though we don't know for sure
+             return !Tuple(request.header(h_Vias).front().param(p_received), 0, UNKNOWN_TRANSPORT).isPrivateAddress();
          }
       }
       return true;
@@ -2205,7 +2217,6 @@ Helper::isClientBehindNAT(const SipMessage& request, bool privateToPublicOnly)
    return false;
 }
 
-
 Tuple
 Helper::getClientPublicAddress(const SipMessage& request)
 {
@@ -2231,12 +2242,19 @@ Helper::getClientPublicAddress(const SipMessage& request)
       }
 
       // Check IP from Via sentHost
-      Tuple address(it->sentHost(), 0, UNKNOWN_TRANSPORT);
-      if(!address.isPrivateAddress())
+      if(DnsUtil::isIpV4Address(it->sentHost())  // Ensure the via host is an IP address (note: web-rtc uses hostnames here instead)
+#ifdef USE_IPv6
+          || DnsUtil::isIpV6Address(it->sentHost())
+#endif
+          )
       {
-         address.setPort(it->exists(p_rport) ? it->param(p_rport).port() : it->sentPort());
-         address.setType(Tuple::toTransport(it->transport()));
-         return address;
+         Tuple address(it->sentHost(), 0, UNKNOWN_TRANSPORT);
+         if(!address.isPrivateAddress())
+         {
+            address.setPort(it->exists(p_rport) ? it->param(p_rport).port() : it->sentPort());
+            address.setType(Tuple::toTransport(it->transport()));
+            return address;
+         }
       }
 
       if(it == request.header(h_Vias).begin()) break;
