@@ -642,7 +642,7 @@ SipMessage::encodeBrief(EncodeStream& str) const
       {
          str << getTransactionId();
       }
-      catch(SipMessage::Exception&)
+      catch(BaseException&)  // Could be SipMessage::Exception or ParseException
       {
          str << "BAD-VIA";
       }
@@ -1181,6 +1181,7 @@ SipMessage::addHeader(Headers::Type header, const char* headerName, int headerLe
 {
    if (header != Headers::UNKNOWN)
    {
+      assert(header >= Headers::UNKNOWN && header < Headers::MAX_HEADERS);
       HeaderFieldValueList* hfvl=0;
       if (mHeaderIndices[header] == 0)
       {
