@@ -206,6 +206,9 @@ TlsConnection::checkState()
                {
                   case EINTR:
                   case EAGAIN:
+#if EAGAIN != EWOULDBLOCK
+                  case EWOULDBLOCK:  // Treat EGAIN and EWOULDBLOCK as the same: http://stackoverflow.com/questions/7003234/which-systems-define-eagain-and-ewouldblock-as-different-values
+#endif
                      StackLog( << "try later");
                      return mTlsState;
                }
@@ -359,7 +362,7 @@ TlsConnection::read(char* buf, int count )
          {
             char buf[256];
             ERR_error_string_n(err,buf,sizeof(buf));
-            ErrLog( << "Got TLS read ret=" << bytesRead << " error=" << err  << " " << buf  );
+            ErrLog( << "Got TLS read ret=" << bytesRead << " error=" << err  << " " << buf << (err==5?" - intermediate certificates may be missing from local PEM file" : "") );
             return -1;
          }
          break;
