@@ -26,6 +26,12 @@ ConfigParse::~ConfigParse()
 {
 }
 
+void
+ConfigParse::parseConfig(int argc, char** argv, const resip::Data& defaultConfigFilename)
+{
+   ConfigParse::parseConfig(argc, argv, defaultConfigFilename, 0);
+}
+
 void 
 ConfigParse::parseConfig(int argc, char** argv, const resip::Data& defaultConfigFilename, int skipCount)
 {
@@ -129,10 +135,9 @@ ConfigParse::parseConfigFile(const Data& filename)
    const char * anchor;
    while(getline(configFile, sline)) 
    {
-      Data line(sline);
       Data name;
       Data value;
-      ParseBuffer pb(line);
+      ParseBuffer pb(sline.c_str(), sline.size());
 
       pb.skipWhitespace();
       anchor = pb.position();
