@@ -1,6 +1,8 @@
 #include "rutil/FileSystem.hxx"
 #include "rutil/Logger.hxx"
 
+#include <sys/stat.h>
+
 #include <cassert>
 using namespace resip;
 
@@ -27,13 +29,20 @@ FileSystem::Directory::iterator::iterator(const Directory& dir)
 {
    assert(!dir.getPath().empty());   
    //InfoLog(<< "FileSystem::Directory::iterator::iterator: " << dir.getPath());   
+   mPath = dir.getPath();
    if ((mNixDir = opendir( dir.getPath().c_str() )))
    {
+      errno = 0;
       mDirent = readdir(mNixDir);
+      if(errno != 0)
+      {
+         throw Exception("Failed readdir", __FILE__, __LINE__);
+      }
       if (mDirent)
       {
          //InfoLog(<< "FileSystem::Directory::iterator::iterator, first file " << mFile);   
          mFile = mDirent->d_name;
+         mFullFilename = mPath + '/' + mFile;
       }
    }
    else
@@ -57,10 +66,16 @@ FileSystem::Directory::iterator::operator++()
 {
    if (mDirent)
    {
+      errno = 0;
       mDirent = readdir(mNixDir);
+      if(errno != 0)
+      {
+         throw Exception("Failed readdir", __FILE__, __LINE__);
+      }
       if (mDirent)
       {
          mFile = mDirent->d_name;
+         mFullFilename = mPath + '/' + mFile;
          //InfoLog(<< "FileSystem::Directory::iterator::iterator, next file " << mFile);   
       }
    }
@@ -103,7 +118,18 @@ FileSystem::Directory::iterator::operator->() const
 bool
 FileSystem::Directory::iterator::is_directory() const
 {
+#if HAVE_STRUCT_DIRENT_D_TYPE
    return mDirent->d_type == DT_DIR;
+#else
+   struct stat s;
+   StackLog(<<"calling stat() for " << mDirent->d_name);
+   if(stat(mFullFilename.c_str(), &s) < 0)
+   {
+      ErrLog(<<"Error calling stat() for " << mFullFilename.c_str() << ": " << strerror(errno));
+      throw Exception("stat() failed", __FILE__, __LINE__);
+   }
+   return S_ISDIR(s.st_mode);
+#endif
 }
 #else
 
@@ -135,6 +161,7 @@ FileSystem::Directory::iterator::iterator(const Directory& dir)
    else
    {
       mFile = fileData.cFileName;
+      mFullFilename = mPath + '/' + mFile;
    }
 }
 
@@ -164,6 +191,7 @@ FileSystem::Directory::iterator::operator++()
    else
    {
       mFile = fileData.cFileName;
+      mFullFilename = mPath + '/' + mFile;
       mIsDirectory = (fileData.dwFileAttributes & FILE_ATTRIBUTE_DEVICE) > 0;
    }  
    return *this;
