@@ -366,14 +366,26 @@ Log::tags(Log::Level level,
         << GetCurrentThreadId() << Log::delim
         << file << ":" << line;
 #else // #if defined( WIN32 ) || defined( __APPLE__ )
-   strm << mDescriptions[level+1] << Log::delim
-        << timestamp(ts) << Log::delim  
-//        << mHostname << Log::delim  
-        << mAppName << Log::delim
-        << subsystem << Log::delim 
-//        << mPid << Log::delim
-        << pthread_self() << Log::delim
-        << pfile << ":" << line;
+   if(resip::Log::getLoggerData().type() == Syslog)
+   {
+      strm << mDescriptions[level+1] << Log::delim
+           << timestamp(ts) << Log::delim
+   //        << mHostname << Log::delim
+           << mAppName << Log::delim
+           << subsystem << Log::delim
+           << mPid << Log::delim
+           << pthread_self() << Log::delim
+           << pfile << ":" << line;
+   }
+   else
+      strm << mDescriptions[level+1] << Log::delim
+           << timestamp(ts) << Log::delim  
+   //        << mHostname << Log::delim  
+           << mAppName << Log::delim
+           << subsystem << Log::delim 
+   //        << mPid << Log::delim
+           << pthread_self() << Log::delim
+           << pfile << ":" << line;
 #endif
    return strm;
 }
@@ -428,7 +440,7 @@ Log::timestamp(Data& res)
    char msbuf[5];
    /* Dividing (without remainder) by 1000 rounds the microseconds
       measure to the nearest millisecond. */
-   sprintf(msbuf, ".%3.3ld", long(tv.tv_usec / 1000));
+   snprintf(msbuf, 5, ".%3.3ld", long(tv.tv_usec / 1000));
 
    int datebufCharsRemaining = datebufSize - (int)strlen(datebuf);
    strncat (datebuf, msbuf, datebufCharsRemaining - 1);
