@@ -44,6 +44,10 @@
 #include <Windns.h>
 #endif
 
+#ifdef __ANDROID__
+#include <sys/system_properties.h>
+#endif
+
 #include "ares.h"
 #include "ares_private.h"
 
@@ -254,22 +258,21 @@ static int init_by_options(ares_channel channel, struct ares_options *options,
      for (i = 0; i < options->nservers; i++)
      {
 #ifdef USE_IPV6
-	channel->servers[i].family = options->servers[i].family;
-	if (options->servers[i].family == AF_INET6)
-	{
-	  channel->servers[i].addr6 = options->servers[i].addr6;
-	}
-	else
-	{
-	  assert( channel->servers[i].family == AF_INET );
-	  channel->servers[i].addr = options->servers[i].addr;
-	}
+	    channel->servers[i].family = options->servers[i].family;
+	    if (options->servers[i].family == AF_INET6)
+	    {
+	       channel->servers[i].addr6 = options->servers[i].addr6;
+	    }
+	    else
+	    {
+	       assert( channel->servers[i].family == AF_INET );
+		   channel->servers[i].addr = options->servers[i].addr;
+	    }
 #else	  
-	channel->servers[i].addr = options->servers[i];
+	    channel->servers[i].addr = options->servers[i];
 #endif
-	// .kw. why is this inside the loop?
-        channel->nservers = options->nservers;
      }
+     channel->nservers = options->nservers;
   }
 
   /* Copy the domains, if given.  Keep channel->ndomains consistent so
@@ -485,12 +488,13 @@ static int init_by_defaults(ares_channel channel)
      /*
       * Way of getting nameservers that should work on all Windows from 98 on.
       */
-      FIXED_INFO *     FixedInfo;
-      ULONG            ulOutBufLen;
+      FIXED_INFO *     FixedInfo = NULL;
+      ULONG            ulOutBufLen = 0;
       DWORD            dwRetVal;
       IP_ADDR_STRING * pIPAddr;
 	  HANDLE           hLib;
-	  int num;
+	  int              num;
+      int              trys = 0;
 	  DWORD (WINAPI *GetNetworkParams)(FIXED_INFO*, DWORD*); 
 
 	  hLib = LoadLibrary(TEXT("iphlpapi.dll"));
@@ -506,20 +510,22 @@ static int init_by_defaults(ares_channel channel)
 		  return ARES_ENOTIMP;
 	  }
       //printf("ARES: figuring out DNS servers\n");
-      FixedInfo = (FIXED_INFO *) GlobalAlloc( GPTR, sizeof( FIXED_INFO ) );
-      ulOutBufLen = sizeof( FIXED_INFO );
-
-      if( ERROR_BUFFER_OVERFLOW == (*GetNetworkParams)( FixedInfo, &ulOutBufLen ) ) 
-	  {
-        GlobalFree( FixedInfo );
+      while(ERROR_BUFFER_OVERFLOW == (dwRetVal = GetNetworkParams( FixedInfo, &ulOutBufLen )) && trys++ < 5)
+      {
+        if(FixedInfo != NULL)
+        {
+            GlobalFree( FixedInfo );
+        }
         FixedInfo = (FIXED_INFO *)GlobalAlloc( GPTR, ulOutBufLen );
       }
-
-      if ( dwRetVal = (*GetNetworkParams)( FixedInfo, &ulOutBufLen ) )
+      if( dwRetVal != 0)
       {
-        //printf("ARES: couldn't get network params\n");
-        GlobalFree( FixedInfo );
-  	    FreeLibrary(hLib);
+        //printf("ARES: couldn't get network params, dwRet=0x%x\n", dwRetVal);
+        if(FixedInfo != NULL)
+        {
+            GlobalFree( FixedInfo );
+        }
+        FreeLibrary(hLib);
         return ARES_ENODATA;
       }
       else
@@ -539,6 +545,14 @@ static int init_by_defaults(ares_channel channel)
           num++;
           pIPAddr = pIPAddr ->Next;
         }
+        //if(num == 0)
+        //{
+        //    printf("ARES: no nameservers! size=%d\n", ulOutBufLen);
+        //}
+        //else
+        //{
+        //    printf("ARES: num nameservers: %d, size=%d\n", num, ulOutBufLen);
+        //}
         if(num>0)
         {
            channel->servers = malloc( (num) * sizeof(struct server_state));
@@ -600,6 +614,57 @@ static int init_by_defaults(ares_channel channel)
 	  }
 #elif defined(__APPLE__) || defined(__MACH__)
       init_by_defaults_systemconfiguration(channel);
+#elif defined(__ANDROID__)
+      int android_prop_found = 0;
+      char props_dns[2][PROP_VALUE_MAX];
+      char prop_name[PROP_NAME_MAX];
+      const char *prop_keys[2] = { "net.dns1", "net.dns2" };
+      int i = 0, j = 0;
+      for(i = 0; i < 2; i++)
+        {
+          props_dns[android_prop_found][0] = 0;
+          const prop_info *prop = __system_property_find(prop_keys[i]);
+          if(prop != NULL)
+            {
+              __system_property_read(prop, NULL, props_dns[android_prop_found]);
+              if(props_dns[android_prop_found][0] != 0)
+                android_prop_found++;
+            }
+        }
+      if(android_prop_found > 0)
+        {
+          channel->servers = malloc( (android_prop_found) * sizeof(struct server_state));
+          if (!channel->servers)
+            {
+              return ARES_ENOMEM;
+            }
+          memset(channel->servers, '\0', android_prop_found * sizeof(struct server_state));
+
+          for(i = 0; i < android_prop_found; i++)
+            {
+              int rc = inet_pton(AF_INET, props_dns[i], &channel->servers[j].addr.s_addr);
+              if(rc == 1)
+                {
+#ifdef USE_IPV6
+                  channel->servers[j].family = AF_INET;
+#endif
+                  j++;
+                }
+#ifdef USE_IPV6
+              else
+                {
+                  rc = inet_pton(AF_INET6, props_dns[i], &channel->servers[j].addr6.s_addr);
+                  if(rc == 1)
+                    {
+                      channel->servers[j].family = AF_INET6;
+                      j++;
+                    }
+                }
+#endif
+            }
+          // how many really are valid IP addresses?
+          channel->nservers = j;
+        }
 #else
 		/* If nobody specified servers, try a local named. */
 		channel->servers = malloc(sizeof(struct server_state));
@@ -987,6 +1052,7 @@ static int get_physical_address(char *physicalAddr, int physicalAddrBufSz, int*
   }
   else
   {
+    //printf("ARES: couldn't get adapters addresses, dwRet=0x%x\n", dwRet);
     rc = ARES_ENODATA;
     goto cleanup;
   }
@@ -994,6 +1060,7 @@ static int get_physical_address(char *physicalAddr, int physicalAddrBufSz, int*
   dwRet = (*GetAdaptersAddressesProc)(AF_UNSPEC, 0, NULL, pAdapterAddresses, &dwSize);
   if (dwRet != ERROR_SUCCESS)
   {
+    //printf("ARES: couldn't get adapters addresses (2), dwRet=0x%x\n", dwRet);
     rc = ARES_ENODATA;
     goto cleanup;
   }
